﻿using Microsoft.Extensions.Configuration;
using System;
using System.Data.Common;
using System.IO;

namespace ProxmoxConnector.Server.Application.Services.Environment
{
    public class EnvironmentConfigurator
    {
        private readonly string _workspace;
        private readonly string _databaseConnection;

        public EnvironmentConfigurator(IConfigurationRoot configuration)
        {
            _workspace = configuration.GetValue<string>("Workspace");
            _databaseConnection = configuration.GetConnectionString("DatabaseConnection");
        }

        public void Configure()
        {
            if (string.IsNullOrEmpty(_workspace))
                throw new Exception($"Workspace path is empty! Check 'Workspace' parameter.");

            if (!Directory.Exists(_workspace))
                Directory.CreateDirectory(_workspace);
        }

        public (string databasePath, string workspace) GetStorageTools()
        {
            var builder = new DbConnectionStringBuilder
            {
                ConnectionString = _databaseConnection
            };

            var dataSource = builder["Data Source"].ToString();
            var databasePath = dataSource.Replace("{Workspace}", _workspace);
            return (databasePath, _workspace);
        }
    }
}
